@@ -1,5 +1,5 @@
 ;;; emacspeak-aumix.el --- Configure audio device settings
-;;; $Id: emacspeak-aumix.el 4532 2007-05-04 01:13:44Z tv.raman.tv $
+;;; $Id: emacspeak-aumix.el 5798 2008-08-22 17:35:01Z tv.raman.tv $
 ;;; $Author: tv.raman.tv $
 ;;; Description:  Emacspeak extension to conveniently set audio display
 ;;; Keywords: Emacspeak, Audio Desktop
@@ -8,8 +8,8 @@
 ;;; LCD Archive Entry:
 ;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
 ;;; A speech interface to Emacs |
-;;; $Date: 2007-05-03 18:13:44 -0700 (Thu, 03 May 2007) $ |
-;;;  $Revision: 4532 $ |
+;;; $Date: 2007-08-25 18:28:19 -0700 (Sat, 25 Aug 2007) $ |
+;;;  $Revision: 4670 $ |
 ;;; Location undetermined
 ;;;
 
@@ -104,13 +104,6 @@ display."
   :group 'emacspeak-aumix
   :type 'boolean)
 
-(defcustom emacspeak-aumix-midi-available-p nil
-  "*Set to T if   midi is available."
-  :group 'emacspeak-aumix
-  :type 'boolean)
-
-(setq emacspeak-aumix-midi-available-p
-      (file-exists-p "/usr/bin/stdiosynth"))
 ;;}}}
 ;;{{{ emacspeak-aumix
 
