@@ -1,5 +1,5 @@
 ;;; emacspeak-gomoku.el --- Speech enable the game of Gomoku
-;;; $Id: emacspeak-gomoku.el 4532 2007-05-04 01:13:44Z tv.raman.tv $
+;;; $Id: emacspeak-gomoku.el 5798 2008-08-22 17:35:01Z tv.raman.tv $
 ;;; $Author: tv.raman.tv $ 
 ;;; Description: Auditory interface to gomoku
 ;;; Keywords: Emacspeak, Speak, Spoken Output, gomoku
@@ -8,7 +8,7 @@
 ;;; LCD Archive Entry:
 ;;; emacspeak| T. V. Raman |raman@cs.cornell.edu 
 ;;; A speech interface to Emacs |
-;;; $Date: 2007-05-03 18:13:44 -0700 (Thu, 03 May 2007) $ |
+;;; $Date: 2008-06-21 14:58:40 -0700 (Sat, 21 Jun 2008) $ |
 ;;;  $Revision: 4532 $ | 
 ;;; Location undetermined
 ;;;
@@ -350,10 +350,10 @@
 (defun emacspeak-gomoku-setup-keys ()
   "Add additional keybindings"
   (declare (special gomoku-mode-map))
-  (loop for key in (where-is-internal 'backward-char gomoku-mode-map)
+  (loop for key in (where-is-internal 'backward-char (list gomoku-mode-map))
         do
         (define-key gomoku-mode-map key 'gomoku-move-left))
-  (loop for key in (where-is-internal 'forward-char gomoku-mode-map)
+  (loop for key in (where-is-internal 'forward-char (list gomoku-mode-map))
         do
         (define-key gomoku-mode-map key 'gomoku-move-right))
   (define-key gomoku-mode-map "\t"
