@@ -1,5 +1,5 @@
 ;;; emacspeak-jabber.el --- Speech-Enable jabber
-;;; $Id: emacspeak-jabber.el 5560 2008-04-15 13:25:36Z tv.raman.tv $
+;;; $Id: emacspeak-jabber.el 6070 2008-11-25 21:27:54Z tv.raman.tv $
 ;;; $Author: tv.raman.tv $
 ;;; Description: speech-enable jabber
 ;;; Keywords: Emacspeak, jabber
@@ -116,6 +116,7 @@
   "Produce auditory icon."
   (when (interactive-p)
     (emacspeak-auditory-icon 'close-object)))
+
 (loop for f in
       '(jabber-chat-with
         jabber-chat-with-jid-at-point)
@@ -126,6 +127,7 @@
           (when (interactive-p)
             (emacspeak-auditory-icon 'open-object)
             (emacspeak-speak-mode-line)))))
+
 ;;}}}
 ;;{{{ alerts
 (defcustom emacspeak-jabber-speak-presence-alerts nil
@@ -200,6 +202,68 @@
 (emacspeak-pronounce-augment-pronunciations 'jabber-mode
                                             emacspeak-pronounce-internet-smileys-pronunciations)
 
+;;}}}
+;;{{{ Browse chat buffers:
+
+;;; Relies on jabber prompt pattern.
+;;; Search forward/back for "^[", check prompt face to determine
+;;; local/foreign, then speak  text in appropriate face.
+
+(defun emacspeak-jabber-chat-speak-this-message ()
+  "Speaks message starting on current line.
+Assumes point is at the front of the message.
+Returns a cons (start . end) that delimits the message."
+  (interactive)
+  (unless (eq major-mode 'jabber-chat-mode)
+    (error "Not in a Jabber chat buffer."))
+  (let ((start nil)
+        (end nil))
+    (save-excursion
+      (when (interactive-p)
+        (unless (looking-at "^\\[")
+          (re-search-backward "^\\[" nil t)))
+      (setq start
+            (goto-char
+             (next-single-property-change (point) 'face)))
+      (setq end
+            (goto-char
+             (next-single-property-change (point) 'face)))
+      (emacspeak-speak-region start end))
+    (cons start end)))
+
+(defun emacspeak-jabber-chat-next-message ()
+  "Move forward to and speak the next message in this chat
+session."
+  (interactive)
+  (unless (eq major-mode 'jabber-chat-mode)
+    (error "Not in a Jabber chat buffer."))
+  (re-search-forward "^\\["nil t)
+  (let ((extent (emacspeak-jabber-chat-speak-this-message)))
+    (emacspeak-auditory-icon 'large-movement)
+    (goto-char (cdr extent))))
+
+(defun emacspeak-jabber-chat-previous-message ()
+  "Move backward to and speak the previous message in this chat
+session."
+  (interactive)
+  (unless (eq major-mode 'jabber-chat-mode)
+    (error "Not in a Jabber chat buffer."))
+  (beginning-of-line)
+  (re-search-backward "^\\["nil t)
+  (let ((extent (emacspeak-jabber-chat-speak-this-message)))
+    (emacspeak-auditory-icon 'large-movement)
+    (goto-char (car extent))))
+      
+
+(when (boundp 'jabber-chat-mode-map)
+  (loop for k in
+        '(
+          ("\M-n" emacspeak-jabber-chat-next-message)
+          ("\M-p" emacspeak-jabber-chat-previous-message)
+          ("\M- " emacspeak-jabber-chat-speak-this-message))
+        do
+        (emacspeak-keymap-update  jabber-chat-mode-map k)))
+
 ;;}}}
 (provide 'emacspeak-jabber)
 ;;{{{ end of file
