@@ -1,5 +1,5 @@
 ;;; emacspeak-man.el --- Speech enable Man mode -- Use this for UNIX Man pages
-;;; $Id: emacspeak-man.el 4532 2007-05-04 01:13:44Z tv.raman.tv $
+;;; $Id: emacspeak-man.el 5798 2008-08-22 17:35:01Z tv.raman.tv $
 ;;; $Author: tv.raman.tv $ 
 ;;; DescriptionEmacspeak extensions for man-mode
 ;;; Keywords:emacspeak, audio interface to emacs man 
@@ -8,8 +8,8 @@
 ;;; LCD Archive Entry:
 ;;; emacspeak| T. V. Raman |raman@cs.cornell.edu 
 ;;; A speech interface to Emacs |
-;;; $Date: 2007-05-03 18:13:44 -0700 (Thu, 03 May 2007) $ |
-;;;  $Revision: 4532 $ | 
+;;; $Date: 2008-06-21 10:50:41 -0700 (Sat, 21 Jun 2008) $ |
+;;;  $Revision: 4546 $ | 
 ;;; Location undetermined
 ;;;
 
@@ -124,6 +124,12 @@ Also provide an auditory icon"
     (emacspeak-auditory-icon 'close-object)
     (emacspeak-speak-mode-line )))
 
+(defadvice Man-kill (after emacspeak pre act )
+  "Announce buffer that is current"
+  (when (interactive-p)
+    (emacspeak-auditory-icon 'close-object)
+    (emacspeak-speak-mode-line )))
+
 (defadvice manual-entry (after emacspeak pre act )
   "Provide auditory feedback"
   (when (interactive-p)
@@ -154,7 +160,7 @@ Also provide an auditory icon"
   "emacspeak-view" "Move current line to top of window"  t)
 (declaim (special Man-mode-map))
 (eval-when (load)
-  (emacspeak-keymap-remove-emacspeak-edit-commands Man-mode-map))
+  )
 (declaim (special  Man-mode-map))
 (define-key Man-mode-map ";"
   'emacspeak-speak-current-window)
