@@ -1,5 +1,5 @@
 ;;; emacspeak-vm.el --- Speech enable VM -- A powerful mail agent (and the one I use)
-;;; $Id: emacspeak-vm.el 4532 2007-05-04 01:13:44Z tv.raman.tv $
+;;; $Id: emacspeak-vm.el 5798 2008-08-22 17:35:01Z tv.raman.tv $
 ;;; $Author: tv.raman.tv $
 ;;; Description:  Emacspeak extension to speech enhance vm
 ;;; Keywords: Emacspeak, VM, Email, Spoken Output, Voice annotations
@@ -8,8 +8,8 @@
 ;;; LCD Archive Entry:
 ;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
 ;;; A speech interface to Emacs |
-;;; $Date: 2007-05-03 18:13:44 -0700 (Thu, 03 May 2007) $ |
-;;;  $Revision: 4532 $ |
+;;; $Date: 2008-07-31 10:49:44 -0700 (Thu, 31 Jul 2008) $ |
+;;;  $Revision: 4557 $ |
 ;;; Location undetermined
 ;;;
 
@@ -68,7 +68,7 @@ Note that some badly formed mime messages  cause trouble."
   "Setup function placed on vm-mode-hook by Emacspeak."
   (declare (special  dtk-punctuation-mode emacspeak-vm-voice-lock-messages
                      dtk-allcaps-beep))
-  (setq dtk-punctuation-mode 'some)
+  (setq dtk-punctuation-mode 'all)
   (when dtk-allcaps-beep
     (dtk-toggle-allcaps-beep))
   (emacspeak-dtk-sync)
@@ -89,15 +89,13 @@ Note that some badly formed mime messages  cause trouble."
         (dtk-stop-immediately t))
     (emacspeak-kill-buffer-carefully "*Completions*")
     ad-do-it
-    (let ((completions-buffer (get-buffer "*Completions*")))
-      (if (> (point) prior)
-          (dtk-speak (buffer-substring prior (point )))
-        (when (and completions-buffer
-                   (window-live-p (get-buffer-window completions-buffer )))
-          (save-excursion
-            (set-buffer completions-buffer )
-            (emacspeak-prepare-completions-buffer)
-            (dtk-speak (buffer-string ))))))
+    (if (> (point) prior)
+        (tts-with-punctuations
+         'all
+         (if (> (length (emacspeak-get-minibuffer-contents)) 0)
+             (dtk-speak (emacspeak-get-minibuffer-contents))
+           (emacspeak-speak-line)))
+      (emacspeak-speak-completions-if-available))
     ad-return-value))
 
 (defadvice vm-minibuffer-complete-word-and-exit (around emacspeak pre act)
@@ -106,15 +104,13 @@ Note that some badly formed mime messages  cause trouble."
         (dtk-stop-immediately t))
     (emacspeak-kill-buffer-carefully "*Completions*")
     ad-do-it
-    (let ((completions-buffer (get-buffer "*Completions*")))
-      (if (> (point) prior)
-          (dtk-speak (buffer-substring prior (point )))
-        (when (and completions-buffer
-                   (window-live-p (get-buffer-window completions-buffer )))
-          (save-excursion
-            (set-buffer completions-buffer )
-            (emacspeak-prepare-completions-buffer)
-            (dtk-speak (buffer-string ))))))
+    (if (> (point) prior)
+        (tts-with-punctuations
+         'all
+         (if (> (length (emacspeak-get-minibuffer-contents)) 0)
+             (dtk-speak (emacspeak-get-minibuffer-contents))
+           (emacspeak-speak-line)))
+      (emacspeak-speak-completions-if-available))
     ad-return-value))
 
 ;;}}}
@@ -218,34 +214,31 @@ Note that some badly formed mime messages  cause trouble."
                     vm-virtual-folder-definition
                     vm-ml-message-new
                     vm-ml-message-number vm-ml-highest-message-number ))
-  (dtk-stop)
-  (emacspeak-dtk-sync)
-  (let ((dtk-stop-immediately nil ))
-    (when (buffer-modified-p )
-      (dtk-tone 700 70))
-    (cond
-     (vm-virtual-folder-definition
-      (dtk-speak
-       (format "Message %s of %s from virtual folder %s"
-               vm-ml-message-number vm-ml-highest-message-number
-               (car vm-virtual-folder-definition))))
-     (t (dtk-speak
-         (format "Message %s of %s,    %s %s %s  %s"
-                 vm-ml-message-number vm-ml-highest-message-number
-                 (if vm-ml-message-new "new" "")
-                 (if vm-ml-message-unread "unread" "")
-                 (if vm-ml-message-read "read" "")
-                 (mapconcat
-                  (function (lambda(item)
-                              (let ((var (car item))
-                                    (value (cadr item )))
-                                (cond
-                                 ((and (boundp var) (eval var ))
-                                  (if (symbolp value)
-                                      (eval value)
-                                    value))
-                                 (t "")))))
-                  (cdr vm-ml-message-attributes-alist)   " ")))))))
+  (when (buffer-modified-p )
+    (dtk-tone 700 70))
+  (cond
+   (vm-virtual-folder-definition
+    (dtk-speak
+     (format "Message %s of %s from virtual folder %s"
+	     vm-ml-message-number vm-ml-highest-message-number
+	     (car vm-virtual-folder-definition))))
+   (t (dtk-speak
+       (format "Message %s of %s,    %s %s %s  %s"
+	       vm-ml-message-number vm-ml-highest-message-number
+	       (if vm-ml-message-new "new" "")
+	       (if vm-ml-message-unread "unread" "")
+	       (if vm-ml-message-read "read" "")
+	       (mapconcat
+		(function (lambda(item)
+			    (let ((var (car item))
+				  (value (cadr item )))
+			      (cond
+			       ((and (boundp var) (eval var ))
+				(if (symbolp value)
+				    (eval value)
+				  value))
+			       (t "")))))
+		(cdr vm-ml-message-attributes-alist)   " "))))))
 
 ;;}}}
 ;;{{{  Moving between messages
@@ -293,16 +286,13 @@ Then speak the screenful. "
 (declaim (special vm-mode-map))
 (eval-when (load)
   (load-library "vm-vars")
-  (emacspeak-keymap-remove-emacspeak-edit-commands
-   vm-mode-map))
+  )
 
 (declaim (special vm-mode-map))
 (define-key vm-mode-map "\M-\C-m" 'widget-button-press)
 (define-key vm-mode-map "y" 'emacspeak-vm-yank-header)
-(define-key vm-mode-map "\M-\t"
-  'emacspeak-vm-next-button)
-(define-key vm-mode-map  "j"
-  'emacspeak-hide-or-expose-all-blocks)
+(define-key vm-mode-map "\M-\t" 'emacspeak-vm-next-button)
+(define-key vm-mode-map  "j" 'emacspeak-hide-or-expose-all-blocks)
 (define-key vm-mode-map  "\M-g" 'vm-goto-message)
 (define-key vm-mode-map "J" 'vm-discard-cached-data)
 (define-key vm-mode-map "." 'emacspeak-vm-browse-message)
@@ -385,7 +375,9 @@ Then speak the screenful. "
 (defadvice vm-quit (after emacspeak pre act )
   "Provide an auditory icon if requested"
   (when (interactive-p)
-    (emacspeak-auditory-icon 'close-object)))
+    (emacspeak-auditory-icon 'close-object)
+    (message "%s"
+             (emacspeak-speak-mode-line))))
 
 ;;}}}
 ;;{{{ catching up on folders
@@ -406,7 +398,7 @@ Then speak the screenful. "
                    global-map
                    emacspeak-prefix
                    emacspeak-keymap))
-(define-key vm-mode-map "C" 'emacspeak-vm-catch-up-all-messages)
+(define-key vm-mode-map "\M-c" 'emacspeak-vm-catch-up-all-messages)
 (define-key vm-mode-map "\M-j" 'emacspeak-vm-locate-subject-line)
 (define-key vm-mode-map "," 'emacspeak-vm-speak-message)
 (define-key vm-mode-map "\M-l" 'emacspeak-vm-speak-labels)
