@@ -1,5 +1,5 @@
 ;;; emacspeak-we.el --- Transform Web Pages Using XSLT
-;;; $Id: emacspeak-we.el 5471 2008-02-24 20:36:21Z tv.raman.tv $
+;;; $Id: emacspeak-we.el 6029 2008-11-05 17:43:04Z tv.raman.tv $
 ;;; $Author: tv.raman.tv $
 ;;; Description:  Edit/Transform Web Pages using XSLT
 ;;; Keywords: Emacspeak,  Audio Desktop Web, XSLT
@@ -8,7 +8,7 @@
 ;;; LCD Archive Entry:
 ;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
 ;;; A speech interface to Emacs |
-;;; $Date: 2008-02-24 12:36:21 -0800 (Sun, 24 Feb 2008) $ |
+;;; $Date: 2008-08-04 09:12:03 -0700 (Mon, 04 Aug 2008) $ |
 ;;;  $Revision: 4532 $ |
 ;;; Location undetermined
 ;;;
@@ -571,6 +571,33 @@ Tables are specified by containing  match pattern
                 ',(copy-sequence values))))))
     (kill-buffer content)))
 
+
+(defvar emacspeak-we-buffer-role-cache nil
+  "Caches role attribute values for current buffer.")
+
+(make-variable-buffer-local 'emacspeak-we-buffer-role-cache)
+
+(defsubst emacspeak-we-build-role-cache ()
+  "Build role cache and forward it to rendered page."
+  (let ((values nil)
+        (content (clone-buffer)))
+    (save-excursion
+      (set-buffer content)
+      (setq buffer-undo-list t)
+      (emacspeak-xslt-run
+       (emacspeak-xslt-get "role-values.xsl")
+       (point-min) (point-max))
+      (setq values (split-string (buffer-string))))
+    (add-hook
+     'emacspeak-web-post-process-hook
+     (eval
+      `(function
+        (lambda nil
+          (declare (special  emacspeak-we-buffer-role-cache))
+          (setq emacspeak-we-buffer-role-cache
+                ',(copy-sequence values))))))
+    (kill-buffer content)))
+
 ;;;###autoload
 (defun emacspeak-we-extract-by-class (class    url &optional speak)
   "Extract elements having specified class attribute from HTML. Extracts
@@ -802,13 +829,22 @@ specifies the page to extract contents  from."
 ;;}}}
 ;;{{{ xpath  filter
 
+(defvar emacspeak-we-xpath-filter-history 
+(list
+ "//p"
+"//p|//div"
+  "//p|//ol|//ul|//dl|//h1|//h2|//h3|//h4|//h5|//h6|//blockquote")
+"History list recording XPath filters we've used.")
+
+(put 'emacspeak-we-xpath-filter-history 'history-length 10)
+
 (defvar emacspeak-we-xpath-filter nil
   "Buffer local variable specifying a XPath filter for following
 urls.")
 
 (make-variable-buffer-local 'emacspeak-we-xpath-filter)
 (defcustom emacspeak-we-recent-xpath-filter
-  "//p|ol|ul|dl|h1|h2|h3|h4|h5|h6|blockquote|div"
+  "//p|//ol|//ul|//dl|//h1|//h2|//h3|//h4|//h5|//h6|//blockquote|//div"
   "Caches most recently used xpath filter.
 Can be customized to set up initial default."
   :type 'string
@@ -822,7 +858,7 @@ interactive prefix arg. If there is a known rewrite url rule, that is
 used as well."
   (interactive "P")
   (declare (special emacspeak-we-xpath-filter
-                    emacspeak-we-recent-xpath-filter
+                    emacspeak-we-recent-xpath-filter emacspeak-we-xpath-filter-history
                     emacspeak-we-url-rewrite-rule))
   (emacspeak-webutils-browser-check)
   (let ((url (funcall emacspeak-webutils-url-at-point))
@@ -836,8 +872,12 @@ used as well."
              url)))
     (when (or prompt (null emacspeak-we-xpath-filter))
       (setq emacspeak-we-xpath-filter
-            (read-from-minibuffer  "Specify XPath: "
-                                   emacspeak-we-recent-xpath-filter))
+            (read-from-minibuffer
+             "Specify XPath: "
+             nil nil nil
+             'emacspeak-we-xpath-filter-history
+             emacspeak-we-recent-xpath-filter))
+      (pushnew emacspeak-we-xpath-filter emacspeak-we-xpath-filter-history)
       (setq emacspeak-we-recent-xpath-filter
             emacspeak-we-xpath-filter))
     (emacspeak-we-xslt-filter emacspeak-we-xpath-filter
@@ -902,7 +942,7 @@ and provide a completion list of applicable  property values. Filter document by
   (let* ((completion-ignore-case t)
          (choices
           (mapcar 'symbol-name (intersection
-                      '(id class style)
+                      '(id class style role)
                       (emacspeak-webutils-property-names-from-html-stack (emacspeak-w3-html-stack)))))
          (property
           (read
